
/*
Example 1
*/

option formdlim="-";

data _null_;
   if _N_=1 then patternID=prxparse("/Zack/");
   retain patternID;
   input address $80.;
   position = prxmatch(patternID, address);
   if position ^= 0 then put address=;
   datalines;
Zack Johnson, 153 First Str, Chapel Hill, NC27514
Dan Zack, 67891 64th st, Brea, CA
Sally Johns, 4 Moritz Street, Duarte, CA 91010
;



/*
Example 2
*/
data _null_;
   patternID=prxparse("/Zack/o");
   input address $80.;
   position = prxmatch(patternID, address);
   if position ^= 0 then put address=;
   datalines;
Zack Johnson, 153 First Str, Chapel Hill, NC27514
Dan Zack, 67891 64th st, Brea, CA
Sally Johns, 4 Moritz Street, Duarte, CA 91010
;


/*
Example 3
*/

data _null_;
   patternID=prxparse("/\w\w\s?\d{5}/o");
   input address $80.;
   position = prxmatch(patternID, address);
   if position ^= 0 then put address= position=;
   datalines;
Zack Johnson, 153 First Str, Chapel Hill, NC27514
Dan Zack, 67891 64th st, Brea, CA
Sally Johns, 4 Moritz Street, Duarte, CA 91010
;

/*
Example 4
*/
data ex4 (keep=address zip);
    patternID=prxparse("/\w\w\s?\d{5}/o");
	patternID2=prxparse("/\d{5}/o");
    input address $80.;
    call prxsubstr(patternID, address, position, length);
	if position ^= 0 then do;
		state_zip = substr(address, position, length);
        call prxsubstr(patternID2, state_zip, position_zip, length_zip);
		zip = substr(state_zip, position_zip, length_zip);
	end;
	else zip = " ";
    datalines;
Zack Johnson, 153 First Str, Chapel Hill, NC27514
Dan Zack, 67891 64th st, Brea, CA
Sally Johns, 4 Moritz Street, Duarte, CA 91010
;

proc print data=ex4;
run;


/*
Example 5
*/


data ex5 (keep=address zip);
    patternID=prxparse("/(\w\w)\s?(\d{5})/o");
    input address $80.;
	position = prxmatch(patternID, address);
	if position ^= 0 then do;
		call prxposn(patternID, 2, start, length);
		zip = substr(address, start, length);
	end;
	else zip = " ";
    datalines;
Zack Johnson, 153 First Str, Chapel Hill, NC27514
Dan Zack, 67891 64th st, Brea, CA
Sally Johns, 4 Moritz Street, Duarte, CA 91010
;

proc print data=ex5;
run;




/*
Example 6
*/


data ex6 (keep=address zip);
    patternID=prxparse("/(\w\w)\s?(\d{5})/o");
    input address $80.;
	position = prxmatch(patternID, address);
	if position ^= 0 then do;
		zip = prxposn(patternID, 2, address);
	end;
	else zip = " ";
    datalines;
Zack Johnson, 153 First Str, Chapel Hill, NC27514
Dan Zack, 67891 64th st, Brea, CA
Sally Johns, 4 Moritz Street, Duarte, CA 91010
;

proc print data=ex6;
run;


/*
Example 7
*/
data _null_;
    input address $80.;
	new_address=prxchange("s/\s+[sS]t(reet|r)?/ Street/o", -1, address);
	put new_address=;
    datalines;
Zack Johnson, 153 First Str, Chapel Hill, NC27514
Dan Zack, 67891 64th st, Brea, CA
Sally Johns, 4 Moritz Street, Duarte, CA 91010
;

/*
Example 8
*/
data _null_;
    input address $80.;
	new_address=prxchange("s/^(\w\w+)\s+(\w\w+)/$2, $1/o", -1, address);
	new_address1=prxchange("s/\s+[sS]t(reet|r)?/ Street/o", -1, new_address);
	put new_address1=;
    datalines;
Zack Johnson, 153 First Str, Chapel Hill, NC27514
Dan Zack, 67891 64th st, Brea, CA
Sally Johns, 4 Moritz Street, Duarte, CA 91010
;

/*
Example 9
*/
data _null_;
    input address $80.;
    length new_address $80; 
    patternID=prxparse("s/^(\w\w+)\s+(\w\w+)/$2, $1/o");
    call prxchange(patternID, -1, address, new_address);
    put new_address=;
    datalines;
Zack Johnson, 153 First Str, Chapel Hill, NC27514
Dan Zack, 67891 64th st, Brea, CA
Sally Johns, 4 Moritz Street, Duarte, CA 91010
;


/*
Example 10
*/

data ex10 (keep=numbers which);
    input numbers $15.;
	patternID=prxparse("/(one)|(two)|(three)/o");
	position = prxmatch (patternID, numbers);
	if position then do;
		which=prxparen(patternID);
		output;
	end;
    datalines;
one two three
two three one
three one two
four five six
;
proc print data=ex10;
run;


data ex10 (keep=numbers which);
    input numbers $15.;
	patternID=prxparse("/((one)|(two)|(three))/o");
	position = prxmatch (patternID, numbers);
	if position then do;
		which=prxparen(patternID);
		output;
	end;
    datalines;
one two three
two XXX YYY
XXX YYY three
four five six
;
proc print data=ex10;
run;



/*
Example 11
*/
data _null_;  
    input1 = "\(([2-9]\d\d)\) ?[2-9]\d\d-\d{4}";  
    input2 = "([2-9]\d\d)-[2-9]\d\d-\d{4}";  
    both_input = "/(" || input1 || ")|(" || input2 || ")/o";  
    patternID = prxparse(both_input);      
    OC_ID = prxparse("/714|949/o");  

    length areacode $ 3;
    input address $80.;

    if prxmatch(patternID, address) then do;
         which_format = prxparen(patternID);  
         call prxposn(patternID, which_format, pos, len);  
         areacode = substr(address, pos, len); 
         if prxmatch(OC_ID, areacode) then  put "In OC:" address=;
    end;
    datalines; 
Zack Johnson, 153 First Str, Chapel Hill, NC27514 (828) 345-2345
Dan Zack, 67891 64th st, Brea, CA 714-320-1000
Sally Johns, 4 Moritz Street, Duarte, CA 91010 310-232-0001
Eric Johnson, 112 Dublin Ln, Irvine, CA (949) 230-3209
;
/*
Example 12
*/

data ex12 (keep=address num1-num5);
	patternID=prxparse("/\d+/o");
    input address $80.;
    start = 1;
	stop = length(address);
	call prxnext(patternID, start, stop, address, position, length);
	array num[5] $;
	do i = 1 to 5 while (position > 0);
	    num[i]=  substr(address, position, length);
		call prxnext(patternID, start, stop, address, position, length);
	end;
   datalines;
Zack Johnson, 153 First Str, Chapel Hill, NC27514 (828) 345-2345
Dan Zack, 67891 64th st, Brea, CA 714-320-1000
Sally Johns, 4 Moritz Street, Duarte, CA 91010 310-232-0001
Eric Johnson, 112 Dublin Ln, Irvine, CA (949) 230-3209
;

proc print data=ex12;
run;


